==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/CreateUserTypeRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CreateUserTypeRequest
 */
@JsonPropertyOrder({ CreateUserTypeRequest.JSON_PROPERTY_NAME, CreateUserTypeRequest.JSON_PROPERTY_DISPLAY_NAME,
        CreateUserTypeRequest.JSON_PROPERTY_DESCRIPTION })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class CreateUserTypeRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public static final String JSON_PROPERTY_DISPLAY_NAME = "displayName";
    private String displayName;

    public static final String JSON_PROPERTY_DESCRIPTION = "description";
    private String description;

    public CreateUserTypeRequest() {
    }

    public CreateUserTypeRequest name(String name) {

        this.name = name;
        return this;
    }

    /**
     * The updated human-readable name for the User Type
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The updated human-readable name for the User Type")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    public CreateUserTypeRequest displayName(String displayName) {

        this.displayName = displayName;
        return this;
    }

    /**
     * The updated human-readable display name for the User Type
     *
     * @return displayName
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The updated human-readable display name for the User Type")
    @JsonProperty(JSON_PROPERTY_DISPLAY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getDisplayName() {
        return displayName;
    }

    @JsonProperty(JSON_PROPERTY_DISPLAY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDisplayName(String displayName) {
        this.displayName = displayName;
    }

    public CreateUserTypeRequest description(String description) {

        this.description = description;
        return this;
    }

    /**
     * The updated human-readable description of the User Type
     *
     * @return description
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The updated human-readable description of the User Type")
    @JsonProperty(JSON_PROPERTY_DESCRIPTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getDescription() {
        return description;
    }

    @JsonProperty(JSON_PROPERTY_DESCRIPTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDescription(String description) {
        this.description = description;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CreateUserTypeRequest createUserTypeRequest = (CreateUserTypeRequest) o;
        return Objects.equals(this.name, createUserTypeRequest.name)
                && Objects.equals(this.displayName, createUserTypeRequest.displayName)
                && Objects.equals(this.description, createUserTypeRequest.description);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(name, displayName, description);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CreateUserTypeRequest {\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("    displayName: ").append(toIndentedString(displayName)).append("\n");
        sb.append("    description: ").append(toIndentedString(description)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/CreateUserTypeRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CreateUserTypeRequest
 */
@JsonPropertyOrder({ CreateUserTypeRequest.JSON_PROPERTY_NAME, CreateUserTypeRequest.JSON_PROPERTY_DISPLAY_NAME,
        CreateUserTypeRequest.JSON_PROPERTY_DESCRIPTION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class CreateUserTypeRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public static final String JSON_PROPERTY_DISPLAY_NAME = "displayName";
    private String displayName;

    public static final String JSON_PROPERTY_DESCRIPTION = "description";
    private String description;

    public CreateUserTypeRequest() {
    }

    public CreateUserTypeRequest name(String name) {

        this.name = name;
        return this;
    }

    /**
     * The updated human-readable name for the User Type
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The updated human-readable name for the User Type")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    public CreateUserTypeRequest displayName(String displayName) {

        this.displayName = displayName;
        return this;
    }

    /**
     * The updated human-readable display name for the User Type
     *
     * @return displayName
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The updated human-readable display name for the User Type")
    @JsonProperty(JSON_PROPERTY_DISPLAY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getDisplayName() {
        return displayName;
    }

    @JsonProperty(JSON_PROPERTY_DISPLAY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDisplayName(String displayName) {
        this.displayName = displayName;
    }

    public CreateUserTypeRequest description(String description) {

        this.description = description;
        return this;
    }

    /**
     * The updated human-readable description of the User Type
     *
     * @return description
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The updated human-readable description of the User Type")
    @JsonProperty(JSON_PROPERTY_DESCRIPTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getDescription() {
        return description;
    }

    @JsonProperty(JSON_PROPERTY_DESCRIPTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDescription(String description) {
        this.description = description;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CreateUserTypeRequest createUserTypeRequest = (CreateUserTypeRequest) o;
        return Objects.equals(this.name, createUserTypeRequest.name)
                && Objects.equals(this.displayName, createUserTypeRequest.displayName)
                && Objects.equals(this.description, createUserTypeRequest.description);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(name, displayName, description);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CreateUserTypeRequest {\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("    displayName: ").append(toIndentedString(displayName)).append("\n");
        sb.append("    description: ").append(toIndentedString(description)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
